@@ -6,28 +6,35 @@ Attaches Sphinx-Gallery to Sphinx in order to generate the galleries
 when building the documentation.
 """
 
-
 import codecs
 import copy
 from datetime import timedelta, datetime
 from difflib import get_close_matches
-from importlib import import_module
+from pathlib import Path
+from textwrap import indent
 import re
 import os
 import pathlib
 from xml.sax.saxutils import quoteattr, escape
+from itertools import chain
 
 from sphinx.errors import ConfigError, ExtensionError
 import sphinx.util
-from sphinx.util.console import red
+from sphinx.util.console import blue, red, purple, bold
 from . import glr_path_static, __version__ as _sg_version
 from .utils import _replace_md5, _has_optipng, _has_pypandoc, _has_graphviz
 from .backreferences import _finalize_backreferences
-from .gen_rst import generate_dir_rst, SPHX_GLR_SIG, _get_memory_base, _get_readme
-from .scrapers import _scraper_dict, _reset_dict, _import_matplotlib
+from .gen_rst import (
+    generate_dir_rst,
+    SPHX_GLR_SIG,
+    _get_readme,
+    _get_class,
+    _get_callables,
+    _get_call_memory_and_base,
+)
+from .scrapers import _import_matplotlib
 from .docs_resolv import embed_code_links
 from .downloads import generate_zipfiles
-from .sorting import NumberOfCodeLinesSortKey
 from .interactive_example import (
     copy_binder_files,
     check_binder_conf,
@@ -37,6 +44,9 @@ from .interactive_example import pre_configure_jupyterlite_sphinx
 from .interactive_example import post_configure_jupyterlite_sphinx
 from .interactive_example import create_jupyterlite_contents
 from .directives import MiniGallery, ImageSg, imagesg_addnode
+from .recommender import ExampleRecommender, _write_recommendations
+from .sorting import ExplicitOrder
+
 
 _KNOWN_CSS = (
     "sg_gallery",
@@ -61,9 +71,13 @@ DEFAULT_GALLERY_CONF = {
     "filename_pattern": re.escape(os.sep) + "plot",
     "ignore_pattern": r"__init__\.py",
     "examples_dirs": os.path.join("..", "examples"),
+    "example_extensions": {".py"},
+    "filetype_parsers": {},
+    "notebook_extensions": {".py"},
     "reset_argv": DefaultResetArgv(),
     "subsection_order": None,
-    "within_subsection_order": NumberOfCodeLinesSortKey,
+    "within_subsection_order": "NumberOfCodeLinesSortKey",
+    "minigallery_sort_order": None,
     "gallery_dirs": "auto_examples",
     "backreferences_dir": None,
     "doc_module": (),
@@ -80,6 +94,7 @@ DEFAULT_GALLERY_CONF = {
     "download_all_examples": True,
     "abort_on_example_error": False,
     "only_warn_on_example_error": False,
+    "recommender": {"enable": False},
     "failing_examples": {},
     "passing_examples": [],
     "stale_examples": [],  # ones that did not need to be run due to md5sum
@@ -148,14 +163,11 @@ def _update_gallery_conf_builder_inited(
     src_dir,
     plot_gallery=True,
     abort_on_example_error=False,
-    lang="python",
     builder_name="html",
 ):
     sphinx_gallery_conf.update(plot_gallery=plot_gallery)
     sphinx_gallery_conf.update(abort_on_example_error=abort_on_example_error)
     sphinx_gallery_conf["src_dir"] = src_dir
-    lang = lang if lang in ("python", "python3", "default") else "python"
-    sphinx_gallery_conf["lang"] = lang
     # Make it easy to know which builder we're in
     sphinx_gallery_conf["builder_name"] = builder_name
 
@@ -184,7 +196,14 @@ def _fill_gallery_conf_defaults(sphinx_gallery_conf, app=None, check_keys=True):
         "run_stale_examples",
     ):
         gallery_conf[key] = _bool_eval(gallery_conf[key])
-    gallery_conf["app"] = app
+    gallery_conf["default_role"] = ""
+    gallery_conf["source_suffix"] = {".rst": "restructuredtext"}
+    if app is not None:
+        if app.config["default_role"]:
+            gallery_conf["default_role"] = app.config["default_role"]
+        gallery_conf["source_suffix"] = app.config["source_suffix"]
+        if isinstance(gallery_conf["source_suffix"], str):
+            gallery_conf["source_suffix"] = {gallery_conf["source_suffix"]: None}
 
     # Check capture_repr
     capture_repr = gallery_conf["capture_repr"]
@@ -206,65 +225,19 @@ def _fill_gallery_conf_defaults(sphinx_gallery_conf, app=None, check_keys=True):
         )
 
     # deal with show_memory
-    gallery_conf["memory_base"] = 0.0
-    if gallery_conf["show_memory"]:
-        if not callable(gallery_conf["show_memory"]):  # True-like
-            try:
-                from memory_profiler import memory_usage  # noqa
-            except ImportError:
-                logger.warning(
-                    "Please install 'memory_profiler' to enable "
-                    "peak memory measurements."
-                )
-                gallery_conf["show_memory"] = False
-            else:
+    _get_call_memory_and_base(gallery_conf)
 
-                def call_memory(func):
-                    mem, out = memory_usage(
-                        func, max_usage=True, retval=True, multiprocess=True
-                    )
-                    try:
-                        mem = mem[0]  # old MP always returned a list
-                    except TypeError:  # 'float' object is not subscriptable
-                        pass
-                    return mem, out
+    # check callables
+    for key in (
+        "image_scrapers",
+        "reset_argv",
+        "minigallery_sort_order",
+        "reset_modules",
+    ):
+        if key == "minigallery_sort_order" and gallery_conf[key] is None:
+            continue
+        _get_callables(gallery_conf, key)
 
-                gallery_conf["call_memory"] = call_memory
-                gallery_conf["memory_base"] = _get_memory_base(gallery_conf)
-        else:
-            gallery_conf["call_memory"] = gallery_conf["show_memory"]
-    if not gallery_conf["show_memory"]:  # can be set to False above
-
-        def call_memory(func):
-            return 0.0, func()
-
-        gallery_conf["call_memory"] = call_memory
-    assert callable(gallery_conf["call_memory"])
-
-    # deal with scrapers
-    scrapers = gallery_conf["image_scrapers"]
-    if not isinstance(scrapers, (tuple, list)):
-        scrapers = [scrapers]
-    scrapers = list(scrapers)
-    for si, scraper in enumerate(scrapers):
-        if isinstance(scraper, str):
-            if scraper in _scraper_dict:
-                scraper = _scraper_dict[scraper]
-            else:
-                orig_scraper = scraper
-                try:
-                    scraper = import_module(scraper)
-                    scraper = getattr(scraper, "_get_sg_image_scraper")
-                    scraper = scraper()
-                except Exception as exp:
-                    raise ConfigError(
-                        f"Unknown image scraper {orig_scraper!r}, got:\n{exp}"
-                    )
-            scrapers[si] = scraper
-        if not callable(scraper):
-            raise ConfigError(f"Scraper {scraper!r} was not callable")
-    gallery_conf["image_scrapers"] = tuple(scrapers)
-    del scrapers
     # Here we try to set up matplotlib but don't raise an error,
     # we will raise an error later when we actually try to use it
     # (if we do so) in scrapers.py.
@@ -279,6 +252,28 @@ def _fill_gallery_conf_defaults(sphinx_gallery_conf, app=None, check_keys=True):
     except (ImportError, ValueError):
         pass
 
+    # Check for srcset hidpi images
+    srcset = gallery_conf["image_srcset"]
+    if not isinstance(srcset, (list, tuple)):
+        raise ConfigError(
+            "image_srcset must be a list of strings with the "
+            'multiplicative factor followed by an "x", '
+            'e.g. ["2.0x", "1.5x"]'
+        )
+    srcset_mult_facs = set()
+    for st in srcset:
+        if not (isinstance(st, str) and st[-1:] == "x"):
+            raise ConfigError(
+                f"Invalid value for image_srcset parameter: {st!r}. "
+                "Must be a list of strings with the multiplicative "
+                'factor followed by an "x".  e.g. ["2.0x", "1.5x"]'
+            )
+        # "2x" -> "2.0"
+        srcset_mult_facs.add(float(st[:-1]))
+    srcset_mult_facs -= {1}  # 1x is always saved.
+    gallery_conf["image_srcset"] = [*sorted(srcset_mult_facs)]
+    del srcset, srcset_mult_facs
+
     # compress_images
     compress_images = gallery_conf["compress_images"]
     if isinstance(compress_images, str):
@@ -311,19 +306,8 @@ def _fill_gallery_conf_defaults(sphinx_gallery_conf, app=None, check_keys=True):
     gallery_conf["compress_images"] = compress_images
     gallery_conf["compress_images_args"] = compress_images_args
 
-    # deal with resetters
-    resetters = gallery_conf["reset_modules"]
-    if not isinstance(resetters, (tuple, list)):
-        resetters = [resetters]
-    resetters = list(resetters)
-    for ri, resetter in enumerate(resetters):
-        if isinstance(resetter, str):
-            if resetter not in _reset_dict:
-                raise ConfigError(f"Unknown module resetter named {resetter!r}")
-            resetters[ri] = _reset_dict[resetter]
-        elif not callable(resetter):
-            raise ConfigError(f"Module resetter {resetter!r} was not callable")
-    gallery_conf["reset_modules"] = tuple(resetters)
+    # check resetters
+    _get_callables(gallery_conf, "reset_modules")
 
     if not isinstance(gallery_conf["reset_modules_order"], str):
         raise ConfigError(
@@ -337,8 +321,6 @@ def _fill_gallery_conf_defaults(sphinx_gallery_conf, app=None, check_keys=True):
             f"got {gallery_conf['reset_modules_order']!r}"
         )
 
-    del resetters
-
     # Ensure the first cell text is a string if we have it
     first_cell = gallery_conf.get("first_notebook_cell")
     if (not isinstance(first_cell, str)) and (first_cell is not None):
@@ -407,7 +389,8 @@ def _fill_gallery_conf_defaults(sphinx_gallery_conf, app=None, check_keys=True):
 
     # jupyterlite
     gallery_conf["jupyterlite"] = check_jupyterlite_conf(
-        gallery_conf.get("jupyterlite", {}), app
+        gallery_conf["jupyterlite"],
+        app,
     )
 
     if not isinstance(gallery_conf["css"], (list, tuple)):
@@ -417,8 +400,8 @@ def _fill_gallery_conf_defaults(sphinx_gallery_conf, app=None, check_keys=True):
     for css in gallery_conf["css"]:
         if css not in _KNOWN_CSS:
             raise ConfigError(f"Unknown css {css!r}, must be one of {_KNOWN_CSS!r}")
-        if gallery_conf["app"] is not None:  # can be None in testing
-            gallery_conf["app"].add_css_file(css + ".css")
+        if app is not None:  # can be None in testing
+            app.add_css_file(css + ".css")
 
     # check API usage
     if not isinstance(gallery_conf["api_usage_ignore"], str):
@@ -436,6 +419,9 @@ def _fill_gallery_conf_defaults(sphinx_gallery_conf, app=None, check_keys=True):
             f'got {gallery_conf["show_api_usage"]}'
         )
 
+    # classes (not pickleable so need to resolve using fully qualified name)
+    _get_class(gallery_conf, "within_subsection_order")  # make sure it works
+
     _update_gallery_conf_exclude_implicit_doc(gallery_conf)
 
     return gallery_conf
@@ -460,7 +446,12 @@ def get_subsections(srcdir, examples_dir, gallery_conf, check_for_index=True):
     out : list
         sorted list of gallery subsection folder names
     """
-    sortkey = gallery_conf["subsection_order"]
+    if gallery_conf["subsection_order"] is None:
+        sortkey = None
+    else:
+        (sortkey,) = _get_callables(gallery_conf, "subsection_order")
+        if isinstance(sortkey, list):
+            sortkey = ExplicitOrder(sortkey)
     subfolders = [subfolder for subfolder in os.listdir(examples_dir)]
     if check_for_index:
         subfolders = [
@@ -520,9 +511,7 @@ def _format_toctree(items, includehidden=False):
 """
     st += """
 
-   {}\n""".format(
-        "\n   ".join(items)
-    )
+   {}\n""".format("\n   ".join(items))
 
     st += "\n"
 
@@ -661,6 +650,42 @@ def generate_gallery_rst(app):
             costs += subsection_costs
             write_computation_times(gallery_conf, target_dir, subsection_costs)
 
+        # Build recommendation system
+        if gallery_conf["recommender"]["enable"]:
+            try:
+                import numpy as np  # noqa: F401
+            except ImportError:
+                raise ConfigError("gallery_conf['recommender'] requires numpy")
+
+            recommender_params = copy.deepcopy(gallery_conf["recommender"])
+            recommender_params.pop("enable")
+            recommender_params.pop("rubric_header", None)
+            recommender = ExampleRecommender(**recommender_params)
+
+            gallery_py_files = []
+            # root and subsection directories containing python examples
+            gallery_directories = [gallery_dir_abs_path] + subsecs
+            for current_dir in gallery_directories:
+                src_dir = os.path.join(gallery_dir_abs_path, current_dir)
+                # sort python files to have a deterministic input across call
+                py_files = sorted(
+                    [
+                        fname
+                        for fname in Path(src_dir).iterdir()
+                        if fname.suffix == ".py"
+                    ],
+                    key=_get_class(gallery_conf, "within_subsection_order")(src_dir),
+                )
+                gallery_py_files.append(
+                    [os.path.join(src_dir, fname) for fname in py_files]
+                )
+            # flatten the list of list
+            gallery_py_files = list(chain.from_iterable(gallery_py_files))
+
+            recommender.fit(gallery_py_files)
+            for fname in gallery_py_files:
+                _write_recommendations(recommender, fname, gallery_conf)
+
         # generate toctree with subsections
         if gallery_conf["nested_sections"] is True:
             subsections_toctree = _format_toctree(
@@ -673,7 +698,7 @@ def generate_gallery_rst(app):
 
         if gallery_conf["download_all_examples"]:
             download_fhindex = generate_zipfiles(
-                gallery_dir_abs_path, app.builder.srcdir
+                gallery_dir_abs_path, app.builder.srcdir, gallery_conf
             )
             indexst += download_fhindex
 
@@ -686,6 +711,9 @@ def generate_gallery_rst(app):
                 fhindex.write(indexst)
             _replace_md5(index_rst_new, mode="t")
 
+    # Write a single global sg_execution_times
+    write_computation_times(gallery_conf, None, costs)
+
     if gallery_conf["show_api_usage"] is not False:
         _init_api_usage(app.builder.srcdir)
     _finalize_backreferences(seen_backrefs, gallery_conf)
@@ -693,7 +721,7 @@ def generate_gallery_rst(app):
     if gallery_conf["plot_gallery"]:
         logger.info("computation time summary:", color="white")
         lines, lens = _format_for_writing(
-            costs, os.path.normpath(gallery_conf["src_dir"]), kind="console"
+            costs, src_dir=gallery_conf["src_dir"], kind="console"
         )
         for name, t, m in lines:
             text = (f"    - {name}:   ").ljust(lens[0] + 10)
@@ -738,25 +766,24 @@ def _sec_to_readable(t):
     return t
 
 
-def cost_name_key(cost_name):
-    """Cost (time_elapsed, memory_used) sorting function."""
-    cost, name = cost_name
+def _cost_key(cost):
+    """Cost sorting function."""
     # sort by descending computation time, descending memory, alphabetical name
-    return (-cost[0], -cost[1], name)
+    return (-cost["t"], -cost["mem"], cost["src_file"])
 
 
-def _format_for_writing(costs, path, kind="rst"):
+def _format_for_writing(costs, *, src_dir, kind="rst"):
     """Provide formatted computation summary text.
 
     Parameters
     ----------
-    costs: List[Tuple[Tuple[float], str]]
-        List of tuples of computation costs and absolute paths to example, of format:
-        ((time_elapsed, memory_used), example_path).
-    path: str
-        Source directory.
-    kind: 'rst' or 'console', default='rst'
-        Format for printing to 'console' or for writing `sg_execution_times.rst' ('rst')
+    costs: List[Dict]
+        List of dicts of computation costs and paths, see gen_rst.py for details.
+    src_dir : pathlib.Path
+        The Sphinx source directory.
+    kind: 'rst', 'rst-full' or 'console', default='rst'
+        Format for printing to 'console' or for writing `sg_execution_times.rst' ('rst'
+        for single galleries and 'rst-full' for all galleries).
 
     Returns
     -------
@@ -768,17 +795,23 @@ def _format_for_writing(costs, path, kind="rst"):
         Character length of each string in `lines`.
     """
     lines = list()
-    for cost in sorted(costs, key=cost_name_key):
-        if kind == "rst":  # like in sg_execution_times
-            name = ":ref:`sphx_glr_{0}_{1}` (``{1}``)".format(
-                path, os.path.basename(cost[1])
+    for cost in sorted(costs, key=_cost_key):
+        src_file = cost["src_file"]
+        rel_path = os.path.relpath(src_file, src_dir)
+        if kind in ("rst", "rst-full"):  # like in sg_execution_times
+            target_dir_clean = os.path.relpath(cost["target_dir"], src_dir).replace(
+                os.path.sep, "_"
             )
-            t = _sec_to_readable(cost[0][0])
+            paren = rel_path if kind == "rst-full" else os.path.basename(src_file)
+            name = ":ref:`sphx_glr_{0}_{1}` (``{2}``)".format(
+                target_dir_clean, os.path.basename(src_file), paren
+            )
+            t = _sec_to_readable(cost["t"])
         else:  # like in generate_gallery
             assert kind == "console"
-            name = os.path.relpath(cost[1], path)
-            t = f"{cost[0][0]:0.2f} sec"
-        m = f"{cost[0][1]:.1f} MB"
+            name = rel_path
+            t = f'{cost["t"]:0.2f} sec'
+        m = f'{cost["mem"]:.1f} MB'
         lines.append([name, t, m])
     lens = [max(x) for x in zip(*[[len(item) for item in cost] for cost in lines])]
     return lines, lens
@@ -791,39 +824,76 @@ def write_computation_times(gallery_conf, target_dir, costs):
     ----------
     gallery_conf : Dict[str, Any]
         Sphinx-Gallery configuration dictionary.
-    target_dir : str
+    target_dir : str | None
         Path to directory where example python source file are.
-    costs: List[Tuple[Tuple[float], str]]
-        List of tuples of computation costs and absolute paths to example, of format:
-        ((time_elapsed, memory_used), example_path).
+    costs: List[Dict]
+        List of dicts of computation costs and paths, see gen_rst.py for details.
     """
-    total_time = sum(cost[0][0] for cost in costs)
-    if total_time == 0:
+    total_time = sum(cost["t"] for cost in costs)
+    if target_dir is None:  # all galleries together
+        out_dir = gallery_conf["src_dir"]
+        where = "all galleries"
+        kind = "rst-full"
+        ref_extra = ""
+    else:  # a single gallery
+        out_dir = target_dir
+        where = os.path.relpath(target_dir, gallery_conf["src_dir"])
+        kind = "rst"
+        ref_extra = f'{where.replace(os.path.sep, "_")}_'
+    new_ref = f"sphx_glr_{ref_extra}sg_execution_times"
+    out_file = Path(out_dir) / "sg_execution_times.rst"
+    if out_file.is_file() and total_time == 0:  # a re-run
         return
-    target_dir_clean = os.path.relpath(target_dir, gallery_conf["src_dir"]).replace(
-        os.path.sep, "_"
-    )
-    new_ref = f"sphx_glr_{target_dir_clean}_sg_execution_times"
-    with codecs.open(
-        os.path.join(target_dir, "sg_execution_times.rst"), "w", encoding="utf-8"
-    ) as fid:
+    with out_file.open("w", encoding="utf-8") as fid:
         fid.write(SPHX_GLR_COMP_TIMES.format(new_ref))
         fid.write(
-            "**{}** total execution time for **{}** files:\n\n".format(
-                _sec_to_readable(total_time), target_dir_clean
-            )
+            f"**{_sec_to_readable(total_time)}** total execution time for "
+            f"{len(costs)} file{'s' if len(costs) != 1 else ''} **from {where}**:\n\n"
+        )
+        lines, lens = _format_for_writing(
+            costs,
+            src_dir=gallery_conf["src_dir"],
+            kind=kind,
         )
-        lines, lens = _format_for_writing(costs, target_dir_clean)
         del costs
-        hline = "".join(("+" + "-" * (length + 2)) for length in lens) + "+\n"
-        fid.write(hline)
-        format_str = "".join(f"| {{{ii}}} " for ii in range(len(lines[0]))) + "|\n"
-        for line in lines:
-            line = [ll.ljust(len_) for ll, len_ in zip(line, lens)]
-            text = format_str.format(*line)
-            assert len(text) == len(hline)
-            fid.write(text)
-            fid.write(hline)
+        # https://datatables.net/examples/styling/bootstrap5.html
+        fid.write(  # put it in a container to make the scoped style work
+            """\
+.. container::
+
+  .. raw:: html
+
+    <style scoped>
+    <link href="https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/5.3.0/css/bootstrap.min.css" rel="stylesheet" />
+    <link href="https://cdn.datatables.net/1.13.6/css/dataTables.bootstrap5.min.css" rel="stylesheet" />
+    </style>
+    <script src="https://code.jquery.com/jquery-3.7.0.js"></script>
+    <script src="https://cdn.datatables.net/1.13.6/js/jquery.dataTables.min.js"></script>
+    <script src="https://cdn.datatables.net/1.13.6/js/dataTables.bootstrap5.min.js"></script>
+    <script type="text/javascript" class="init">
+    $(document).ready( function () {
+        $('table.sg-datatable').DataTable({order: [[1, 'desc']]});
+    } );
+    </script>
+
+  .. list-table::
+   :header-rows: 1
+   :class: table table-striped sg-datatable
+
+   * - Example
+     - Time
+     - Mem (MB)
+"""  # noqa: E501
+        )
+        # Need at least one entry or Sphinx complains
+        for ex, t, mb in lines or [["N/A", "N/A", "N/A"]]:
+            fid.write(
+                f"""\
+   * - {ex}
+     - {t}
+     - {mb.rsplit(maxsplit=1)[0]}
+"""
+            )  # remove the "MB" from the right
 
 
 def write_api_entries(app, what, name, obj, options, lines):
@@ -865,6 +935,17 @@ def _init_api_usage(gallery_dir):
         pass
 
 
+# Colors from https://personal.sron.nl/~pault/data/colourschemes.pdf
+# 3 Diverging Colour Schemes, Figure 12, plus alpha=AA
+API_COLORS = dict(
+    edge="#00000080",  # gray (by alpha)
+    okay="#98CAE180",  # blue
+    bad_1="#FEDA8B80",  # yellow
+    bad_2="#F67E4B80",  # orange
+    bad_3="#A5002680",  # red
+)
+
+
 def _make_graph(fname, entries, gallery_conf):
     """Make a graph of unused and used API entries.
 
@@ -893,7 +974,17 @@ def _make_graph(fname, entries, gallery_conf):
 
     dg = graphviz.Digraph(
         filename=fname,
-        node_attr={"color": "lightblue2", "style": "filled", "fontsize": "40"},
+        graph_attr={
+            "overlap": "scale",
+            "pad": "0.5",
+        },
+        node_attr={
+            "color": API_COLORS["okay"],
+            "style": "filled",
+            "fontsize": "20",
+            "shape": "box",
+            "fontname": "Open Sans,Arial",
+        },
     )
 
     if isinstance(entries, list):
@@ -908,9 +999,9 @@ def _make_graph(fname, entries, gallery_conf):
                 node_from = (
                     lut[struct[level]] if struct[level] in lut else struct[level]
                 )
-                dg.attr("node", color="lightblue2")
                 dg.node(node_from)
                 node_to = struct[level + 1]
+                node_kwargs = dict()
                 # count, don't show leaves
                 if len(struct) - 3 == level:
                     leaf_count = 0
@@ -927,21 +1018,18 @@ def _make_graph(fname, entries, gallery_conf):
                             ]
                         ):
                             leaf_count += 1
-                    node_to += f"\n({leaf_count})"
+                    node_to += f" ({leaf_count})"
                     lut[struct[level + 1]] = node_to
                     if leaf_count > 10:
-                        color = "red"
+                        color_key = "bad_3"
                     elif leaf_count > 5:
-                        color = "orange"
+                        color_key = "bad_2"
                     else:
-                        color = "yellow"
-                    dg.attr("node", color=color)
-                else:
-                    dg.attr("node", color="lightblue2")
-                dg.node(node_to)
-                dg.edge(node_from, node_to)
+                        color_key = "bad_1"
+                    node_kwargs["color"] = API_COLORS[color_key]
+                dg.node(node_to, **node_kwargs)
+                dg.edge(node_from, node_to, color=API_COLORS["edge"])
         # add modules with all API entries
-        dg.attr("node", color="lightblue2")
         for module in gallery_conf["_sg_api_entries"]["module"]:
             struct = module.split(".")
             for i in range(len(struct) - 1):
@@ -950,15 +1038,11 @@ def _make_graph(fname, entries, gallery_conf):
     else:
         assert isinstance(entries, dict)
         for entry, refs in entries.items():
-            dg.attr("node", color="lightblue2")
             dg.node(entry)
-            dg.attr("node", color="yellow")
             for ref in refs:
-                dg.node(ref)
-                dg.edge(entry, ref)
-
-    dg.attr(overlap="scale")
-    dg.save(fname)
+                dg.node(ref, color=API_COLORS["bad_1"])
+                dg.edge(entry, ref, color=API_COLORS["edge"])
+    dg.save()
 
 
 def write_api_entry_usage(app, docname, source):
@@ -985,17 +1069,24 @@ def write_api_entry_usage(app, docname, source):
         List whose single element is the contents of the source file
     """
     docname = docname or ""  # can be None on Sphinx 7.2
+    if docname != "sg_api_usage":
+        return
     gallery_conf = app.config.sphinx_gallery_conf
     if gallery_conf["show_api_usage"] is False:
         return
     # since this is done at the gallery directory level (as opposed
     # to in a gallery directory, e.g. auto_examples), it runs last
     # which means that all the api entries will be in gallery_conf
+
+    # Always write at least the title
+    source[0] = SPHX_GLR_ORPHAN.format("sphx_glr_sg_api_usage")
+    title = "Unused API Entries"
+    source[0] += title + "\n" + "^" * len(title) + "\n\n"
     if (
-        "sg_api_usage" not in docname
-        or "_sg_api_entries" not in gallery_conf
+        "_sg_api_entries" not in gallery_conf
         or gallery_conf["backreferences_dir"] is None
     ):
+        source[0] += "No API entries found, not computed.\n\n"
         return
     backreferences_dir = os.path.join(
         gallery_conf["src_dir"], gallery_conf["backreferences_dir"]
@@ -1010,6 +1101,7 @@ def write_api_entry_usage(app, docname, source):
     )
 
     if len(example_files) == 0:
+        source[0] += "No examples run, not computed.\n\n"
         return
 
     def get_entry_type(entry):
@@ -1043,10 +1135,6 @@ def write_api_entry_usage(app, docname, source):
                         example_name = line.split("`")[1]
                         used_api_entries[entry].append(example_name)
 
-    source[0] = SPHX_GLR_ORPHAN.format("sphx_glr_sg_api_usage")
-
-    title = "Unused API Entries"
-    source[0] += title + "\n" + "^" * len(title) + "\n\n"
     for entry in sorted(unused_api_entries):
         source[0] += f"- :{get_entry_type(entry)}:`{entry}`\n"
     source[0] += "\n\n"
@@ -1136,8 +1224,7 @@ def write_junit_xml(gallery_conf, target_dir, costs):
     target_dir : Union[str, pathlib.Path]
         Build directory.
     costs: List[Tuple[Tuple[float], str]]
-        List of tuples of computation costs and absolute paths to example, of format:
-        ((time_elapsed, memory_used), example_path).
+        List of dicts of computation costs and paths, see gen_rst.py for details.
     """
     if not gallery_conf["junit"] or not gallery_conf["plot_gallery"]:
         return
@@ -1151,7 +1238,7 @@ def write_junit_xml(gallery_conf, target_dir, costs):
     src_dir = gallery_conf["src_dir"]
     output = ""
     for cost in costs:
-        (t, _), fname = cost
+        t, fname = cost["t"], cost["src_file"]
         if not any(
             fname in x
             for x in (
@@ -1269,30 +1356,36 @@ def summarize_failing_examples(app, exception):
         gallery_conf
     )
 
+    idt = "    "
     if failing_as_expected:
-        logger.info("Examples failing as expected:", color="brown")
+        logger.info(bold("Examples failing as expected:"), color="blue")
         for fail_example in failing_as_expected:
-            logger.info("%s failed leaving traceback:", fail_example, color="brown")
-            logger.info(gallery_conf["failing_examples"][fail_example], color="brown")
+            path = os.path.relpath(fail_example, gallery_conf["src_dir"])
+            logger.info(
+                f"{bold(blue(path))} failed leaving traceback:\n\n"
+                f"{indent(gallery_conf['failing_examples'][fail_example], idt)}"
+            )
 
     fail_msgs = []
     if failing_unexpectedly:
-        fail_msgs.append(red("Unexpected failing examples:"))
+        fail_msgs.append(bold(red("Unexpected failing examples:\n")))
         for fail_example in failing_unexpectedly:
+            path = os.path.relpath(fail_example, gallery_conf["src_dir"])
             fail_msgs.append(
-                fail_example
-                + " failed leaving traceback:\n"
-                + gallery_conf["failing_examples"][fail_example]
-                + "\n"
+                f"    {bold(red(path))} failed leaving traceback:\n\n"
+                f"{indent(gallery_conf['failing_examples'][fail_example], idt)}"
             )
 
     if passing_unexpectedly:
+        paths = [
+            os.path.relpath(p, gallery_conf["src_dir"]) for p in passing_unexpectedly
+        ]
         fail_msgs.append(
-            red("Examples expected to fail, but not failing:\n")
-            + "Please remove these examples from\n"
-            + "sphinx_gallery_conf['expected_failing_examples']\n"
-            + "in your conf.py file"
-            "\n".join(passing_unexpectedly)
+            bold(red("Examples expected to fail, but not failing:\n\n"))
+            + red("\n".join(indent(p, idt) for p in paths))
+            + "\n\nPlease remove these examples from "
+            + "sphinx_gallery_conf['expected_failing_examples'] "
+            + "in your conf.py file."
         )
 
     # standard message
@@ -1317,9 +1410,14 @@ def summarize_failing_examples(app, exception):
     )
 
     if fail_msgs:
-        fail_message = (
-            "Here is a summary of the problems encountered "
-            "when running the examples\n\n" + "\n".join(fail_msgs) + "\n" + "-" * 79
+        fail_message = bold(
+            purple(
+                "Here is a summary of the problems encountered "
+                "when running the examples:\n\n"
+                + "\n".join(fail_msgs)
+                + "\n"
+                + "-" * 79
+            )
         )
         if gallery_conf["only_warn_on_example_error"]:
             logger.warning(fail_message)
@@ -1402,13 +1500,11 @@ def update_gallery_conf_builder_inited(app):
     plot_gallery = _bool_eval(app.builder.config.plot_gallery)
     src_dir = app.builder.srcdir
     abort_on_example_error = _bool_eval(app.builder.config.abort_on_example_error)
-    lang = app.builder.config.highlight_language
     _update_gallery_conf_builder_inited(
         app.config.sphinx_gallery_conf,
         src_dir,
         plot_gallery=plot_gallery,
         abort_on_example_error=abort_on_example_error,
-        lang=lang,
         builder_name=app.builder.name,
     )
 
