@@ -10,6 +10,7 @@ import json
 
 import pytest
 
+from sphinx.config import is_serializable
 from sphinx.errors import ConfigError, ExtensionError, SphinxWarning
 from sphinx_gallery.gen_gallery import (
     check_duplicate_filenames,
@@ -21,6 +22,7 @@ from sphinx_gallery.gen_gallery import (
     fill_gallery_conf_defaults,
 )
 from sphinx_gallery.interactive_example import create_jupyterlite_contents
+from sphinx_gallery.utils import _escape_ansi
 
 
 def test_bad_config():
@@ -28,12 +30,21 @@ def test_bad_config():
     sphinx_gallery_conf = dict(example_dir="")
     with pytest.raises(
         ConfigError, match="example_dir.*did you mean 'examples_dirs'?.*"
-    ):  # noqa: E501
+    ):
         _fill_gallery_conf_defaults(sphinx_gallery_conf)
     sphinx_gallery_conf = dict(n_subsection_order="")
     with pytest.raises(
         ConfigError, match=r"did you mean one of \['subsection_order', 'within_.*"
-    ):  # noqa: E501
+    ):
+        _fill_gallery_conf_defaults(sphinx_gallery_conf)
+    sphinx_gallery_conf = dict(within_subsection_order="sphinx_gallery.a.b.Key")
+    with pytest.raises(ConfigError, match="must be a fully qualified"):
+        _fill_gallery_conf_defaults(sphinx_gallery_conf)
+    sphinx_gallery_conf = dict(within_subsection_order=1.0)
+    with pytest.raises(ConfigError, match="a fully qualified.*got float"):
+        _fill_gallery_conf_defaults(sphinx_gallery_conf)
+    sphinx_gallery_conf = dict(minigallery_sort_order=int)
+    with pytest.raises(ConfigError, match="Got class rather than callable instance"):
         _fill_gallery_conf_defaults(sphinx_gallery_conf)
 
 
@@ -48,6 +59,17 @@ def test_default_config(sphinx_app_wrapper):
     assert "already present" in str(excinfo.value)
 
 
+def test_serializable(sphinx_app_wrapper):
+    """Test that the default config is serializable."""
+    bad = list()
+    for key, val in _fill_gallery_conf_defaults({}).items():
+        if not is_serializable(val):
+            bad.append(f"{repr(key)}: {repr(val)}")
+
+    bad = "\n".join(bad)
+    assert not bad, f"Non-serializable values found:\n{bad}"
+
+
 @pytest.mark.conf_file(
     content="""
 sphinx_gallery_conf = {
@@ -75,7 +97,7 @@ def test_no_warning_simple_config(sphinx_app_wrapper):
     [
         pytest.param(
             ConfigError,
-            "Unknown module resetter",
+            "Unknown string option for reset_modules",
             id="Resetter unknown",
             marks=pytest.mark.conf_file(
                 content="sphinx_gallery_conf={'reset_modules': ('f',)}"
@@ -83,7 +105,7 @@ def test_no_warning_simple_config(sphinx_app_wrapper):
         ),
         pytest.param(
             ConfigError,
-            "Module resetter .* was not callab",
+            "reset_modules.* must be callable",
             id="Resetter not callable",
             marks=pytest.mark.conf_file(
                 content="sphinx_gallery_conf={'reset_modules': (1.,),}"
@@ -253,11 +275,10 @@ def test_example_sorting_default(sphinx_app_wrapper):
 
 @pytest.mark.conf_file(
     content="""
-from sphinx_gallery.sorting import FileSizeSortKey
 sphinx_gallery_conf = {
     'examples_dirs': 'src',
     'gallery_dirs': 'ex',
-    'within_subsection_order': FileSizeSortKey,
+    'within_subsection_order': "FileSizeSortKey",
 }"""
 )
 def test_example_sorting_filesize(sphinx_app_wrapper):
@@ -268,11 +289,10 @@ def test_example_sorting_filesize(sphinx_app_wrapper):
 
 @pytest.mark.conf_file(
     content="""
-from sphinx_gallery.sorting import FileNameSortKey
 sphinx_gallery_conf = {
     'examples_dirs': 'src',
     'gallery_dirs': 'ex',
-    'within_subsection_order': FileNameSortKey,
+    'within_subsection_order': "FileNameSortKey",
 }"""
 )
 def test_example_sorting_filename(sphinx_app_wrapper):
@@ -283,11 +303,10 @@ def test_example_sorting_filename(sphinx_app_wrapper):
 
 @pytest.mark.conf_file(
     content="""
-from sphinx_gallery.sorting import ExampleTitleSortKey
 sphinx_gallery_conf = {
     'examples_dirs': 'src',
     'gallery_dirs': 'ex',
-    'within_subsection_order': ExampleTitleSortKey,
+    'within_subsection_order': "ExampleTitleSortKey",
 }"""
 )
 def test_example_sorting_title(sphinx_app_wrapper):
@@ -441,8 +460,8 @@ def test_only_warn_on_example_error(sphinx_app_wrapper):
         fid.write("raise ValueError")
     sphinx_app = sphinx_app_wrapper.build_sphinx_app()
 
-    build_warn = sphinx_app._warning.getvalue()
-    assert "plot_3.py failed to execute correctly" in build_warn
+    build_warn = _escape_ansi(sphinx_app._warning.getvalue())
+    assert "plot_3.py unexpectedly failed to execute correctly" in build_warn
     assert "WARNING: Here is a summary of the problems" in build_warn
 
 
@@ -462,7 +481,8 @@ def test_only_warn_on_example_error_sphinx_warning(sphinx_app_wrapper):
         fid.write("raise ValueError")
     with pytest.raises(SphinxWarning) as excinfo:
         sphinx_app_wrapper.build_sphinx_app()
-    assert "plot_3.py failed to execute" in str(excinfo.value)
+    exc = _escape_ansi(str(excinfo.value))
+    assert "plot_3.py unexpectedly failed to execute" in exc
 
 
 @pytest.mark.conf_file(
@@ -476,13 +496,16 @@ sphinx_gallery_conf = {
 def test_examples_not_expected_to_pass(sphinx_app_wrapper):
     with pytest.raises(ExtensionError) as excinfo:
         sphinx_app_wrapper.build_sphinx_app()
-    assert "expected to fail, but not failing" in str(excinfo.value)
+    exc = _escape_ansi(str(excinfo.value))
+    assert "expected to fail, but not failing" in exc
 
 
 @pytest.mark.conf_file(
     content="""
+from sphinx_gallery.gen_rst import _sg_call_memory_noop
+
 sphinx_gallery_conf = {
-    'show_memory': lambda func: (0., func()),
+    'show_memory': _sg_call_memory_noop,
     'gallery_dirs': 'ex',
 }"""
 )
@@ -545,8 +568,9 @@ def test_backreferences_dir_pathlib_config(sphinx_app_wrapper):
     fill_gallery_conf_defaults(app, app.config, check_keys=False)
 
 
-def test_write_computation_times_noop():
-    write_computation_times(None, None, [[[0]]])
+def test_write_computation_times_noop(sphinx_app_wrapper):
+    app = sphinx_app_wrapper.create_sphinx_app()
+    write_computation_times(app.config.sphinx_gallery_conf, None, [])
 
 
 def test_write_api_usage_noop(sphinx_app_wrapper):
@@ -595,6 +619,7 @@ sphinx_gallery_conf = {
 )
 def test_create_jupyterlite_contents(sphinx_app_wrapper):
     """Test that JupyterLite contents are created properly."""
+    pytest.importorskip("jupyterlite_sphinx")
     sphinx_app = sphinx_app_wrapper.create_sphinx_app()
     gallery_conf = sphinx_app.config.sphinx_gallery_conf
 
@@ -624,6 +649,7 @@ sphinx_gallery_conf = {
 )
 def test_create_jupyterlite_contents_non_default_contents(sphinx_app_wrapper):
     """Test that JupyterLite contents are created properly."""
+    pytest.importorskip("jupyterlite_sphinx")
     sphinx_app = sphinx_app_wrapper.create_sphinx_app()
     gallery_conf = sphinx_app.config.sphinx_gallery_conf
 
@@ -652,6 +678,7 @@ def test_create_jupyterlite_contents_without_jupyterlite_sphinx_loaded(
     sphinx_app_wrapper,
 ):
     """Test JupyterLite contents creation without jupyterlite_sphinx loaded."""
+    pytest.importorskip("jupyterlite_sphinx")
     sphinx_app = sphinx_app_wrapper.create_sphinx_app()
 
     create_jupyterlite_contents(sphinx_app, exception=None)
@@ -676,6 +703,7 @@ def test_create_jupyterlite_contents_with_jupyterlite_disabled_via_config(
 
     JupyterLite disabled via config.
     """
+    pytest.importorskip("jupyterlite_sphinx")
     sphinx_app = sphinx_app_wrapper.create_sphinx_app()
 
     create_jupyterlite_contents(sphinx_app, exception=None)
@@ -706,6 +734,7 @@ sphinx_gallery_conf = {
 }"""
 )
 def test_create_jupyterlite_contents_with_modification(sphinx_app_wrapper):
+    pytest.importorskip("jupyterlite_sphinx")
     sphinx_app = sphinx_app_wrapper.create_sphinx_app()
     gallery_conf = sphinx_app.config.sphinx_gallery_conf
 
