@@ -41,7 +41,7 @@ rng = np.random.RandomState(0)
 # test Issue 583
 sphinx_gallery.backreferences.identify_names(
     [("text", "Text block", 1)],
-    sphinx_gallery.backreferences._make_ref_regex({"default_role": None}),
+    sphinx_gallery.backreferences._make_ref_regex(),
 )
 # 583: methods don't link properly
 dc = sphinx_gallery.backreferences.DummyClass()
